#
# spec file for package osmo-msc
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2017-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _lto_cflags %{nil}

%define with_iu 1
Name:           osmo-msc
Version:        1.8.0
Release:        2.3
Summary:        Osmocom's MSC for 2G and 3G circuit-switched mobile networks
License:        AGPL-3.0-or-later AND GPL-2.0-only
Group:          Productivity/Telephony/Servers
URL:            https://osmocom.org/projects/osmomsc/wiki
Source:         %{name}-%{version}.tar.xz
Patch0:         harden_osmo-msc.service.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libdbi-drivers-dbd-sqlite3
BuildRequires:  libtool
BuildRequires:  lksctp-tools-devel
BuildRequires:  pkgconfig >= 0.20
BuildRequires:  pkgconfig(dbi)
BuildRequires:  pkgconfig(libcrypto) >= 0.9.5
BuildRequires:  pkgconfig(libosmo-gsup-client) >= 1.4.0
BuildRequires:  pkgconfig(libosmo-mgcp-client) >= 1.9.0
BuildRequires:  pkgconfig(libosmo-netif) >= 1.1.0
BuildRequires:  pkgconfig(libosmo-sccp) >= 1.5.0
BuildRequires:  pkgconfig(libosmo-sigtran) >= 1.5.0
BuildRequires:  pkgconfig(libosmoabis) >= 1.2.0
BuildRequires:  pkgconfig(libosmocore) >= 1.6.0
BuildRequires:  pkgconfig(libosmoctrl) >= 1.6.0
BuildRequires:  pkgconfig(libosmogsm) >= 1.6.0
BuildRequires:  pkgconfig(libosmovty) >= 1.6.0
BuildRequires:  pkgconfig(libsmpp34) >= 1.14.0
%{?systemd_requires}
%if %{with_iu}
BuildRequires:  pkgconfig(libasn1c) >= 0.9.30
BuildRequires:  pkgconfig(libosmo-ranap) >= 0.3.0
%endif

%description
The Mobile Switching Center (MSC) is the heart of 2G/3G
circuit-switched services.  It terminates the A-interface links from the
Base Station Controllers (BSC) and handles the MM and CC sub-layers of
the Layer 3 protocol from the phones (MS).

This Osmocom implementation of the MSC handles A interfaces via 3GPP
AoIP in an ASP role.  It furthermore implements IETF MGCP against an
external media gateway, such as OsmoMGW.  It does *not* implement MAP
towards a HLR, but the much simpler Osmocom GSUP protocol, which can
be translated to MAP if needed.

%prep
%autosetup -p1

%build
echo "%{version}" >.tarball-version
autoreconf -fi
%configure \
%if %{with_iu}
  --enable-iu \
%endif
  --docdir=%{_docdir}/%{name} \
  --with-systemdsystemunitdir=%{_unitdir}

make %{?_smp_mflags}

%install
%make_install
install -d %{buildroot}/%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rc%{name}

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%check
make %{?_smp_mflags} check || (find . -name testsuite.log -exec cat {} +)

%files
%license COPYING
%doc AUTHORS README
%dir %{_docdir}/%{name}/examples
%dir %{_docdir}/%{name}/examples/osmo-msc
%{_docdir}/%{name}/examples/osmo-msc/osmo-msc.cfg
%{_docdir}/%{name}/examples/osmo-msc/osmo-msc_custom-sccp.cfg
%{_docdir}/%{name}/examples/osmo-msc/osmo-msc_multi-cs7.cfg
%{_bindir}/osmo-msc
%{_unitdir}/%{name}.service
%{_sbindir}/rc%{name}
%dir %{_sysconfdir}/osmocom
%config(noreplace) %{_sysconfdir}/osmocom/osmo-msc.cfg

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Fri Nov 19 2021 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.8.0
  * http://git.osmocom.org/osmo-msc/plain/debian/changelog?h=1.8.0
* Wed Oct 13 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_osmo-msc.service.patch
* Thu Jun 11 2020 Martin Hauke <mardnh@gmx.de>
- Set CFLAGS+=-fcommon to workaround gcc10 errors (boo#1160244)
* Thu Jan  9 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.6.1
  Bugfix release:
  * libmsc/gsm_04_08.c: fix: verify MI before calling
    vlr_subscr_rx_id_resp()
  * vlr.c: fix condition to check MSISDN presence
* Sat Jan  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.6.0
  * MNCC v6: add optional SDP to the socket protocol
  * add sdp_msg API: SDP parsing/composition
  * BSSMAP: decode Codec List (BSS Supported)
  * vlr_auth_fsm: on SAI use the GSUP provided GMM cause code
  * paging: Send SGsAP-SERVICE-ABORT-REQUEST on paging timeout
  * sgs_iface: Accept messages with unknown TLV elements
  * fix error on BSSMAP Cipher Mode Complete L3 msg IE
  * Implement a global switch on the network to disable call waiting.
  * mncc: send payload type matching chosen codec
- Update to new upstream release 1.5.0
  * replace osmo_counter with stat_items
  * Use GSM23003_MSISDN_MAX_DIGITS from libosmogsm
  * libmsc/gsm_04_11.c: properly handle MMTS indication
  * vty: Add option to enable osmux towards BSCs
  * vty: make retrieve-imeisv-early configurable
  * Allow MME name preformatted as FQDN in SGsAP
  * sms queue: avoid repeated Paging for a failed SMS
  * Add SGs Interface
* Sun Nov 10 2019 Martin Hauke <mardnh@gmx.de>
- Disable LTO for now since it breaks compilation of the tests
  See: https://osmocom.org/issues/4115
* Wed Jan 30 2019 mardnh@gmx.de
- Update to new upstream release 1.3.1
  * Implementation of MSC-originated CLASSMARK inquiry procedure for
    MS/UE without early classmark sending to allow A5/3 encryption
  * mncc: fix byte ordering of IP-Address in mncc
  * various improvements on state introspection via VTY
  * forward SS / USSD messages via GSUP to HLR rather than
    processing it in MSC
  * optional forward of SMS via GSUP to/from HLR rather than using
    internal SMSC
  * fix Classmark Update without VLR subscriber
  * vty: add SCCP related vty commands
  * GSUP client: send CN domain IE on LU request
  * vty: add command to show all known BSC
  * Full changelogs since 1.1.2:
    http://git.osmocom.org/osmo-msc/plain/debian/changelog?h=1.3.1
    http://git.osmocom.org/osmo-msc/plain/debian/changelog?h=1.3.0
    http://git.osmocom.org/osmo-msc/plain/debian/changelog?h=1.2.0
- Remove patches:
  * osmo-msc-fix-includes.patch
* Sat Mar 17 2018 mardnh@gmx.de
- Build with "--enable-iu"
* Fri Dec 29 2017 mardnh@gmx.de
- Update Patch:
  * osmo-msc-fix-includes.patch (more include fixes)
* Fri Dec 29 2017 jengelh@inai.de
- %%service_* already takes care of restart/removal
* Thu Dec 28 2017 mardnh@gmx.de
- Initial package, version 1.1.2
